#[repr(transparent)]pub struct LoadingBin {
inner: TypedObjectRef<LoadingBin, <LoadingBin as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
A Bin that shows either its child or a loading spinner.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<LoadingBin, <LoadingBin as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl LoadingBin
impl LoadingBin
Sourcepub fn set_child<'a>(
&self,
value: Option<impl Borrow<<<PhantomData<Option<Widget>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_child<'a>( &self, value: Option<impl Borrow<<<PhantomData<Option<Widget>> as Property>::Value as HasParamSpec>::SetValue>>, )
The child widget.
Sourcepub fn is_loading(&self) -> <PhantomData<bool> as Property>::Value
pub fn is_loading(&self) -> <PhantomData<bool> as Property>::Value
Whether this is showing the spinner.
Sourcepub fn set_is_loading<'a>(
&self,
value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_is_loading<'a>( &self, value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether this is showing the spinner.
Sourcepub fn vhomogeneous(&self) -> <PhantomData<bool> as Property>::Value
pub fn vhomogeneous(&self) -> <PhantomData<bool> as Property>::Value
Whether this should keep the same height when showing the spinner or the content.
Sourcepub fn set_vhomogeneous<'a>(
&self,
value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_vhomogeneous<'a>( &self, value: impl Borrow<<<PhantomData<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether this should keep the same height when showing the spinner or the content.
Sourcepub fn connect_child_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the child property
Sourcepub fn connect_is_loading_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_loading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-loading property
Sourcepub fn connect_vhomogeneous_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_vhomogeneous_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the vhomogeneous property
Sourcepub fn notify_child(&self)
pub fn notify_child(&self)
Notify listeners of a change in the child property
Sourcepub fn notify_is_loading(&self)
pub fn notify_is_loading(&self)
Notify listeners of a change in the is-loading property
Sourcepub fn notify_vhomogeneous(&self)
pub fn notify_vhomogeneous(&self)
Notify listeners of a change in the vhomogeneous property
Sourceimpl LoadingBin
impl LoadingBin